==> migratorydata_client_dart_v6-1.0.1.tar.gz: lib/src/core/websocket/websocket_html.dart <==
import 'dart:convert';
import 'dart:html';
import 'dart:typed_data';

import '../../logger/logger.dart';
import '../cluster_member_info.dart';
import '../configuration.dart';
import '../connection.dart';
import '../scheduler.dart';
import '../util.dart';
import 'websocket_interface.dart';

class WebsocketHelperImpl extends WebsocketInterface {
  WebSocket? ws;

  var data = [];

  @override
  Future<bool> connect(
      ClusterMemberInfo clusterMember,
      String connectionId,
      Connection connection,
      Logger logger,
      Configuration configuration,
      Scheduler scheduler) async {

        data.clear();

    try {
      if (logger.isDebugEnabled()) {
        logger.debug("[html] Connecting to the cluster member: $clusterMember");
      }

      ws = WebSocket(clusterMember.getWsUri());

      ws?.onOpen.listen((e) {
        logger.info("onOPen websocket.");
        if (data.isNotEmpty) {
          for (var d in data) {
            ws?.send(d);
          }
          data.clear();
        }
      });

      ws?.onClose.listen((e) {
        logger.info("onClose websocket.");
        connection.reconnect(
            connectionId, Util.CONNECTION_PASSIVE_CLOSE, "onClose");
      });

      ws?.onError.listen((e) {
        logger.info("onError websocket:${e.toString()}");
        connection.reconnect(
            connectionId, Util.CONNECTION_PASSIVE_CLOSE, "onError");
      });

      ws?.onMessage.listen((MessageEvent e) {
        print('Received message: ${e.data}');
        if (e.data is String) {
          connection.channelRead(
              Uint8List.fromList(utf8.encode(e.data)), connectionId);
        } else {
          connection.channelRead(e.data, connectionId);
        }
      });
    } catch (e) {
      if (logger.isInfoEnabled()) {
        logger.info("Failed to connect: $clusterMember, message: $e");
      }

      scheduler.reconnect(
          connectionId, connection, Util.CONNECTION_ERROR_CLOSE);
      return false; // failed to create socket connection
    }
    return true;
  }

  void close() {
    ws?.close();
    ws = null;
  }

  void write(Uint8List data) {
    if (ws?.readyState == WebSocket.OPEN) {
      ws?.send(data);
    } else {
      //print("[html] channel ready state != open");
      this.data.add(data);
    }
  }
}

==> migratorydata_client_dart_v6-1.0.6.tar.gz: lib/src/core/websocket/websocket_html.dart <==
import 'dart:convert';
import 'dart:html';
import 'dart:typed_data';

import '../../logger/logger.dart';
import '../cluster_member_info.dart';
import '../configuration.dart';
import '../connection.dart';
import '../scheduler.dart';
import '../util.dart';
import 'websocket_interface.dart';

class WebsocketHelperImpl extends WebsocketInterface {
  WebSocket? ws;

  var data = [];

  @override
  Future<bool> connect(
      ClusterMemberInfo clusterMember,
      String connectionId,
      Connection connection,
      Logger logger,
      Configuration configuration,
      Scheduler scheduler) async {

        data.clear();

    try {
      if (logger.isDebugEnabled()) {
        logger.debug("[html] Connecting to the cluster member: $clusterMember");
      }

      ws = WebSocket(clusterMember.getWsUri());

      ws?.onOpen.listen((e) {
        logger.info("onOPen websocket.");
        if (data.isNotEmpty) {
          for (var d in data) {
            ws?.send(d);
          }
          data.clear();
        }
      });

      ws?.onClose.listen((e) {
        logger.info("onClose websocket.");
        connection.reconnect(
            connectionId, Util.CONNECTION_PASSIVE_CLOSE, "onClose");
      });

      ws?.onError.listen((e) {
        logger.info("onError websocket:${e.toString()}");
        connection.reconnect(
            connectionId, Util.CONNECTION_PASSIVE_CLOSE, "onError");
      });

      ws?.onMessage.listen((MessageEvent e) {
        //print('Received message: ${e.data}');
        if (e.data is String) {
          connection.channelRead(
              Uint8List.fromList(utf8.encode(e.data)), connectionId);
        } else {
          connection.channelRead(e.data, connectionId);
        }
      });
    } catch (e) {
      if (logger.isInfoEnabled()) {
        logger.info("Failed to connect: $clusterMember, message: $e");
      }

      scheduler.reconnect(
          connectionId, connection, Util.CONNECTION_ERROR_CLOSE);
      return false; // failed to create socket connection
    }
    return true;
  }

  void close() {
    ws?.close();
    ws = null;
  }

  void write(Uint8List data) {
    if (ws?.readyState == WebSocket.OPEN) {
      ws?.send(data);
    } else {
      //print("[html] channel ready state != open");
      this.data.add(data);
    }
  }
}
